@@ -1,6 +1,8 @@
-from .serialize import dask_serialize, dask_deserialize
+from __future__ import annotations
 
-import pyarrow
+import pyarrow.fs
+
+from distributed.protocol.serialize import dask_deserialize, dask_serialize
 
 if pyarrow.__version__ < "0.10":
     raise ImportError(
@@ -45,3 +47,14 @@ def deserialize_table(header, frames):
     blob = frames[0]
     reader = pyarrow.RecordBatchStreamReader(pyarrow.BufferReader(blob))
     return reader.read_all()
+
+
+@dask_serialize.register(pyarrow.fs.FileInfo)
+def serialize_fileinfo(fileinfo):
+    return {}, [(fileinfo.path, fileinfo.size, fileinfo.mtime_ns)]
+
+
+@dask_deserialize.register(pyarrow.fs.FileInfo)
+def serialize_filesystem(header, frames):
+    path, size, mtime_ns = frames[0]
+    return pyarrow.fs.FileInfo(path=path, size=size, mtime_ns=mtime_ns)
