@@ -54,7 +54,7 @@ from distributed.core import (
 )
 from distributed.deploy import SpecCluster
 from distributed.diagnostics.plugin import WorkerPlugin
-from distributed.metrics import context_meter, time
+from distributed.metrics import _WindowsTime, context_meter, time
 from distributed.nanny import Nanny
 from distributed.node import ServerNode
 from distributed.proctitle import enable_proctitle_on_children
@@ -761,6 +761,7 @@ async def start_cluster(
     Worker: type[ServerNode] = Worker,
     scheduler_kwargs: dict[str, Any] | None = None,
     worker_kwargs: dict[str, Any] | None = None,
+    timeout: float = _TEST_TIMEOUT // 4,
 ) -> tuple[Scheduler, list[ServerNode]]:
     scheduler_kwargs = scheduler_kwargs or {}
     worker_kwargs = worker_kwargs or {}
@@ -797,13 +798,15 @@ async def start_cluster(
         or any(comm.comm is None for comm in s.stream_comms.values())
     ):
         await asyncio.sleep(0.01)
-        if time() > start + 30:
+        if time() > start + timeout:
             await asyncio.gather(*(w.close(timeout=1) for w in workers))
             await s.close()
             check_invalid_worker_transitions(s)
             check_invalid_task_states(s)
             check_worker_fail_hard(s)
-            raise TimeoutError("Cluster creation timeout")
+            raise TimeoutError(
+                "Cluster creation timeout. Workers did not come up and register in time."
+            )
     return s, workers
 
 
@@ -969,18 +972,18 @@ def gen_cluster(
                 workers = []
                 s = None
                 try:
-                    for _ in range(60):
+                    while True:
                         try:
+                            if not deadline.remaining:
+                                raise TimeoutError("Timeout on cluster creation")
                             s, ws = await start_cluster(
                                 nthreads,
                                 scheduler,
                                 security=security,
                                 Worker=Worker,
                                 scheduler_kwargs=scheduler_kwargs,
-                                worker_kwargs=merge(
-                                    {"death_timeout": min(15, int(deadline.remaining))},
-                                    worker_kwargs,
-                                ),
+                                worker_kwargs=worker_kwargs,
+                                timeout=timeout // 4,
                             )
                         except Exception as e:
                             logger.error(
@@ -988,7 +991,6 @@ def gen_cluster(
                                 f"{e.__class__.__name__}: {e}; retrying",
                                 exc_info=True,
                             )
-                            await asyncio.sleep(1)
                         else:
                             workers[:] = ws
                             break
@@ -1541,6 +1543,7 @@ def get_server_ssl_context(
     ctx = ssl.create_default_context(ssl.Purpose.CLIENT_AUTH, cafile=get_cert(ca_file))
     ctx.check_hostname = False
     ctx.verify_mode = ssl.CERT_REQUIRED
+    ctx.verify_flags &= ~ssl.VERIFY_X509_STRICT
     ctx.load_cert_chain(get_cert(certfile), get_cert(keyfile))
     return ctx
 
@@ -1551,6 +1554,7 @@ def get_client_ssl_context(
     ctx = ssl.create_default_context(ssl.Purpose.SERVER_AUTH, cafile=get_cert(ca_file))
     ctx.check_hostname = False
     ctx.verify_mode = ssl.CERT_REQUIRED
+    ctx.verify_flags &= ~ssl.VERIFY_X509_STRICT
     ctx.load_cert_chain(get_cert(certfile), get_cert(keyfile))
     return ctx
 
@@ -2605,14 +2609,14 @@ def no_time_resync():
     """Temporarily disable the automatic resync of distributed.metrics._WindowsTime
     which, every 10 minutes, can cause time() to go backwards a few milliseconds.
 
-    On Linux and MacOSX, this fixture is a no-op.
+    On Linux, MacOSX, and Windows with Python 3.13+ this fixture is a no-op.
 
     See also
     --------
     NoSchedulerDelayWorker
     padded_time
     """
-    if WINDOWS:
+    if isinstance(time, _WindowsTime):
         time()  # Initialize or refresh delta
         bak = time.__self__.next_resync
         time.__self__.next_resync = float("inf")
